# Перекрестные ссылки между файлами

Вторая задача была - сохранить работоспособность перекрестных ссылок
в результирующем документе.

Дело в том, что `pandoc` из коробки умеет собрать из пачки md-файлов
один общий, но ссылки, как например [вот эта], в результирующем документе
будут битыми.

<!-- LINKS -->
[вот эта]: ./01-structure.md
